Introduction
============

.. image:: https://secure.travis-ci.org/collective/collective.searchandreplace.png?branch=master
   :target: https://travis-ci.org/#!/collective/collective.searchandreplace

The collective.searchandreplace product is a Plone Add-on designed to find and replace text in Plone content objects, namely titles, descriptions, and document text. It operates over single or multiple Plone content objects and can preview as well as actuate changes.

Optional features include being able to control searching in subfolders, and matching based on case sensatvity/insensativity.


Compatibility
-------------

From collective.searchandreplace version 5.0, we are compatible with Plone 4.3 and 5.0.

The collective.searchandreplace product was initally built for use with eduCommons by Novell, inc, later improved by EnPraxis.
It is currently maintained by Maurits van Rees.  Plone 5 support added by Gagaro.
